function Ypred = kNNClassify(Xtr, Ytr, k, Xte)
%
% function Y_pred = kNNClassify(Xtr, Ytr,  k, X)
%
% INPUT PARAMETERS
%   Xtr training input
%   Ytr training output 
%   k number of neighbours
%   Xte test input
% 
% OUTPUT PARAMETERS
%   Ypred estimated test output
%
% EXAMPLE
%   Ypred=kNNClassify(Xtr,Ytr,5,Xte);

    n = size(Xtr, 1);
    m = size(Xte, 1);    
    
    if k > n
        k = n;
    end
        
    ylab = unique(Ytr);
    ym = sum(ylab)/2;
    
    % Center output (if output is not in {-1, 1})
    Ytrm = Ytr - ym;
    
    Ypred = zeros(m, 1);

    DistMat = SquareDist(Xtr, Xte);       
    
    for j = 1:m
        SortdDistMat = DistMat(:,j);
        
        [~, I] = sort(SortdDistMat);
        idx = I(1:k);
        
        % Assumes labels are {-1,1}.  
        val = sum(Ytrm(idx)/k);
        
        Ypred(j) = sign(val);
        
    end
    
    % Map back to original output vals
    Ypred = Ypred  + ym;
    
end


